@@ -564,9 +564,10 @@ sub tree {
                             help  => 'portalservers.html',
                             form  => 'simpleInputContainer',
                             nodes => [
-                                'wsdlServer',       'restSessionServer',
-                                'restConfigServer', 'soapSessionServer',
-                                'soapConfigServer', 'exportedAttr',
+                                'wsdlServer',           'restSessionServer',
+                                'restExportSecretKeys', 'restConfigServer',
+                                'soapSessionServer',    'soapConfigServer',
+                                'exportedAttr',
                             ]
                         },
                         {
@@ -689,6 +690,7 @@ sub tree {
                                 'totp2fDisplayExistingSecret',
                                 'totp2fUserCanChangeKey',
                                 'totp2fUserCanRemoveKey',
+                                'totp2fTTL',
                             ]
                         },
                         {
@@ -698,6 +700,7 @@ sub tree {
                             nodes => [
                                 'u2fActivation', 'u2fSelfRegistration',
                                 'u2fAuthnLevel', 'u2fUserCanRemoveKey',
+                                'u2fTTL',
                             ]
                         },
                         {
@@ -745,6 +748,17 @@ sub tree {
                                 'yubikey2fUrl',
                                 'yubikey2fPublicIDSize',
                                 'yubikey2fUserCanRemoveKey',
+                                'yubikey2fTTL',
+                            ],
+                        },
+                        {
+                            title => 'sfRemovedNotification',
+                            help  => 'secondfactor.html',
+                            form  => 'simpleInputContainer',
+                            nodes => [
+                                'sfRemovedMsgRule',  'sfRemovedUseNotif',
+                                'sfRemovedNotifRef', 'sfRemovedNotifTitle',
+                                'sfRemovedNotifMsg',
                             ],
                         },
                         'sfRequired',
@@ -805,6 +819,20 @@ sub tree {
                                         'cspConnect',
                                     ]
                                 },
+                                {
+                                    title => 'crossOrigineResourceSharing',
+                                    help  => 'security.html#portal',
+                                    form  => 'simpleInputContainer',
+                                    nodes => [
+                                        'corsEnabled',
+                                        'corsAllow_Credentials',
+                                        'corsAllow_Headers',
+                                        'corsAllow_Methods',
+                                        'corsAllow_Origin',
+                                        'corsExpose_Headers',
+                                        'corsMax_Age',
+                                    ]
+                                },
                             ]
                         },
                         {
